@@ -721,10 +721,10 @@ static void l4fb_update_dirty_unmap(struct l4fb_screen *screen)
 			if ((l4_fpage_rights(ret_fp) & L4_FPAGE_W)) {
 				if (0)
 					l4x_printf("   %d: addr=%lx size=%x was dirty\n",
-					           j, l4_fpage_page(ret_fp) << L4_PAGESHIFT,
+					           j, l4_fpage_memaddr(ret_fp),
 					           1 << l4_fpage_size(ret_fp));
 				if (!bulksize)
-					bulkstart = l4_fpage_page(ret_fp) << L4_PAGESHIFT;
+					bulkstart = l4_fpage_memaddr(ret_fp);
 				bulksize += 1 << l4_fpage_size(ret_fp);
 
 				continue;
@@ -982,7 +982,7 @@ static int l4fb_init_session(struct fb_info *fb, struct l4fb_screen *screen)
 	}
 
 	ret = L4XV_FN_i(l4re_rm_attach(&fb_addr, fix->smem_len,
-	                               L4RE_RM_SEARCH_ADDR,
+	                               L4RE_RM_F_SEARCH_ADDR | L4RE_RM_F_RW,
 	                               screen->fb_cap | L4_CAP_FPAGE_RW,
 	                               0, 20));
 
